@@ -7,6 +7,8 @@
 #ifndef __SQUID_DIOMSG_H__
 #define __SQUID_DIOMSG_H__
 
+#include "config.h"
+
 enum {
     _MQD_NOP,
     _MQD_OPEN,
@@ -33,5 +35,4 @@ struct diomsg {
     static const int msg_snd_rcv_sz;
 };
 
-
-#endif
+#endif /* __SQUID_DIOMSG_H__ */
