@@ -45,11 +45,11 @@
 #include "squid.h"
 #include "clientStream.h"
 #include "client_side_request.h"
-#include "AuthUserRequest.h"
+#include "auth/UserRequest.h"
 #include "HttpRequest.h"
 #include "ProtoPort.h"
-#include "ACLChecklist.h"
-#include "ACL.h"
+#include "acl/FilledChecklist.h"
+#include "acl/Gadgets.h"
 #include "client_side.h"
 #include "client_side_reply.h"
 #include "Store.h"
@@ -426,7 +426,7 @@ clientFollowXForwardedForCheck(int answer, void *data)
         const char *asciiaddr;
         int l;
         struct in_addr addr;
-        p = request->x_forwarded_for_iterator.buf();
+        p = request->x_forwarded_for_iterator.termedBuf();
         l = request->x_forwarded_for_iterator.size();
 
         /*
@@ -509,8 +509,13 @@ ClientRequestContext::clientAccessCheck()
     }
 #endif /* FOLLOW_X_FORWARDED_FOR */
 
-    acl_checklist = clientAclChecklistCreate(Config.accessList.http, http);
-    acl_checklist->nonBlockingCheck(clientAccessCheckDoneWrapper, this);
+    if (Config.accessList.http) {
+        acl_checklist = clientAclChecklistCreate(Config.accessList.http, http);
+        acl_checklist->nonBlockingCheck(clientAccessCheckDoneWrapper, this);
+    } else {
+        debugs(0, DBG_CRITICAL, "No http_access configuration found. This will block ALL traffic");
+        clientAccessCheckDone(ACCESS_DENIED);
+    }
 }
 
 void
@@ -851,7 +856,7 @@ clientInterpretRequestHeaders(ClientHttpRequest * http)
             int may_pin = 0;
             while ((e = req_hdr->getEntry(&pos))) {
                 if (e->id == HDR_AUTHORIZATION || e->id == HDR_PROXY_AUTHORIZATION) {
-                    const char *value = e->value.buf();
+                    const char *value = e->value.rawBuf();
                     if (strncasecmp(value, "NTLM ", 5) == 0
                             ||
                             strncasecmp(value, "Negotiate ", 10) == 0
@@ -892,7 +897,7 @@ clientInterpretRequestHeaders(ClientHttpRequest * http)
         }
 
 #if FORW_VIA_DB
-        fvdbCountVia(s.buf());
+        fvdbCountVia(s.termedBuf());
 
 #endif
 
@@ -918,13 +923,13 @@ clientInterpretRequestHeaders(ClientHttpRequest * http)
 
     if (req_hdr->has(HDR_X_FORWARDED_FOR)) {
         String s = req_hdr->getList(HDR_X_FORWARDED_FOR);
-        fvdbCountForw(s.buf());
+        fvdbCountForw(s.termedBuf());
         s.clean();
     }
 
 #endif
-    if (request->method == METHOD_TRACE) {
-        request->max_forwards = req_hdr->getInt(HDR_MAX_FORWARDS);
+    if (request->method == METHOD_TRACE || request->method == METHOD_OPTIONS) {
+        request->max_forwards = req_hdr->getInt64(HDR_MAX_FORWARDS);
     }
 
     request->flags.cachable = http->request->cacheable();
@@ -1022,11 +1027,19 @@ ClientRequestContext::clientRedirectDone(char *result)
     http->doCallouts();
 }
 
+/** Test cache allow/deny configuration
+ *  Sets flags.cachable=1 if caching is not denied.
+ */
 void
 ClientRequestContext::checkNoCache()
 {
-    acl_checklist = clientAclChecklistCreate(Config.accessList.noCache, http);
-    acl_checklist->nonBlockingCheck(checkNoCacheDoneWrapper, this);
+    if (Config.accessList.noCache) {
+        acl_checklist = clientAclChecklistCreate(Config.accessList.noCache, http);
+        acl_checklist->nonBlockingCheck(checkNoCacheDoneWrapper, this);
+    } else {
+        /* unless otherwise specified, we try to cache. */
+        checkNoCacheDone(1);
+    }
 }
 
 static void
@@ -1100,12 +1113,9 @@ ClientHttpRequest::sslBumpNeeded() const
 
     debugs(85, 5, HERE << "SslBump possible, checking ACL");
 
-    ACLChecklist check;
+    ACLFilledChecklist check(Config.accessList.ssl_bump, request, NULL);
     check.src_addr = request->client_addr;
     check.my_addr = request->my_addr;
-    check.request = HTTPMSGLOCK(request);
-    check.accessList = cbdataReference(Config.accessList.ssl_bump);
-    /* cbdataReferenceDone() happens in either fastCheck() or ~ACLCheckList */
     return check.fastCheck() == 1;
 }
 
@@ -1272,10 +1282,9 @@ ClientHttpRequest::doCallouts()
     if (!calloutContext->clientside_tos_done) {
         calloutContext->clientside_tos_done = true;
         if (getConn() != NULL) {
-            ACLChecklist ch;
+            ACLFilledChecklist ch(NULL, request, NULL);
             ch.src_addr = request->client_addr;
             ch.my_addr = request->my_addr;
-            ch.request = HTTPMSGLOCK(request);
             int tos = aclMapTOS(Config.accessList.clientside_tos, &ch);
             if (tos)
                 comm_set_tos(getConn()->fd, tos);
