@@ -1,5 +1,5 @@
 /*
- * $Id: snmp_agent.cc,v 1.98 2007/12/27 01:58:19 hno Exp $
+ * $Id$
  *
  * DEBUG: section 49    SNMP Interface
  * AUTHOR: Kostas Anagnostakis
@@ -124,13 +124,13 @@ snmp_confFn(variable_list * Var, snint * ErrP)
 
         case CONF_ST_MMAXSZ:
             Answer = snmp_var_new_integer(Var->name, Var->name_length,
-                                          (snint) Config.memMaxSize >> 20,
+                                          (snint) (Config.memMaxSize >> 20),
                                           ASN_INTEGER);
             break;
 
         case CONF_ST_SWMAXSZ:
             Answer = snmp_var_new_integer(Var->name, Var->name_length,
-                                          (snint) Store::Root().maxSize() >> 10,
+                                          (snint) (Store::Root().maxSize() >> 10),
                                           ASN_INTEGER);
             break;
 
@@ -156,7 +156,7 @@ snmp_confFn(variable_list * Var, snint * ErrP)
     case CONF_LOG_FAC:
         Answer = snmp_var_new(Var->name, Var->name_length);
 
-        if (!(cp = Config.debugOptions))
+        if (!(cp = Debug::debugOptions))
             cp = "None";
 
         Answer->type = ASN_OCTET_STR;
@@ -199,7 +199,7 @@ snmp_meshPtblFn(variable_list * Var, snint * ErrP)
 {
     variable_list *Answer = NULL;
 
-    IPAddress laddr;
+    IpAddress laddr;
     char *cp = NULL;
     peer *p = NULL;
     int cnt = 0;
