@@ -514,7 +514,7 @@ info_get(StoreEntry * sentry)
     storeAppendPrintf(sentry, "\tAverage ICP messages per minute since start:\t%.1f\n",
                       (statCounter.icp.pkts_sent + statCounter.icp.pkts_recv) / (runtime / 60.0));
 
-    storeAppendPrintf(sentry, "\tSelect loop called: %d times, %0.3f ms avg\n",
+    storeAppendPrintf(sentry, "\tSelect loop called: %ld times, %0.3f ms avg\n",
                       statCounter.select_loops, 1000.0 * runtime / statCounter.select_loops);
 
     storeAppendPrintf(sentry, "Cache information for %s:\n",APP_SHORTNAME);
@@ -1367,7 +1367,7 @@ statCountersDump(StoreEntry * sentry)
                       f->unlink.requests);
     storeAppendPrintf(sentry, "page_faults = %d\n",
                       f->page_faults);
-    storeAppendPrintf(sentry, "select_loops = %d\n",
+    storeAppendPrintf(sentry, "select_loops = %ld\n",
                       f->select_loops);
     storeAppendPrintf(sentry, "cpu_time = %f\n",
                       f->cputime);
